# AgentConnectorSpecProvisioning

Determines whether or not the agent will manage upstream user access on this connector. For example mounting shares allocated to the user automatically. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**all_resources** | **bool** | Whether this agent will automatically provision all resources or not. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


